==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridClipboardEventDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDescription } from "./WebGridClipboardEventDescription";
/**
 * @hidden
 */
export let WebGridClipboardEventDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridClipboardEventDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridClipboardEventDescriptionMetadata.a == null) {
                WebGridClipboardEventDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridClipboardEventDescriptionMetadata.c(WebGridClipboardEventDescriptionMetadata.a);
            }
            if (a.j(WebGridClipboardEventDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridClipboardEventDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridClipboardEvent");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebGridClipboardEventDescriptionMetadata.b(a);
            a.aa("WebGridClipboardEvent", () => new WebGridClipboardEventDescription());
            a.z("WebGridClipboardEvent", WebGridClipboardEventDescriptionMetadata.a);
        }
    }
    WebGridClipboardEventDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridClipboardEventDescriptionMetadata, 'WebGridClipboardEventDescriptionMetadata');
    WebGridClipboardEventDescriptionMetadata.a = null;
    return WebGridClipboardEventDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridClipboardEventDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDescription } from "./WebGridClipboardEventDescription";
/**
 * @hidden
 */
export let WebGridClipboardEventDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridClipboardEventDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridClipboardEventDescriptionMetadata.a == null) {
                WebGridClipboardEventDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridClipboardEventDescriptionMetadata.c(WebGridClipboardEventDescriptionMetadata.a);
            }
            if (a.k(WebGridClipboardEventDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridClipboardEventDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridClipboardEvent");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebGridClipboardEventDescriptionMetadata.b(a);
            a.ac("WebGridClipboardEvent", () => new WebGridClipboardEventDescription());
            a.ab("WebGridClipboardEvent", WebGridClipboardEventDescriptionMetadata.a);
        }
    }
    WebGridClipboardEventDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridClipboardEventDescriptionMetadata, 'WebGridClipboardEventDescriptionMetadata');
    WebGridClipboardEventDescriptionMetadata.a = null;
    return WebGridClipboardEventDescriptionMetadata;
})();
